@@ -10,12 +10,13 @@ import uuid
 
 
 DEFAULT_CUSTOM_FORMAT = [
-    'date_time', ' ', 'uuid', ' ', 'level', ': ', 'module', ' - ', 'free_email'
+    'current_date_time', ' ', 'uuid', ' ', 'level', ': ',
+    'module', ' - ', 'free_email'
 ],
 DEFAULT_CUSTOM_DATA = {
-    'date_time': '$RAND',
+    'current_date_time': '$RAND',
     'uuid': [str(uuid.uuid1()) for i in xrange(100)],
-    'level': ['ERROR', 'DEBUG', 'INFO', 'CRITICAL'],
+    'level': ['WARNING', 'ERROR', 'DEBUG', 'INFO', 'CRITICAL'],
     'module': ['module1', 'module2'],
     'free_email': '$RAND',
 }
