@@ -81,7 +81,7 @@ class FileTransport(BaseTransport):
         return data_table
 
 
-class AmqpTransport(BaseTransport):
+class AMQPTransport(BaseTransport):
     """an amqp transport implementation"""
     def __init__(self, config):
         try:
